@@ -210,8 +210,9 @@ class basicImg():
             barcodeData = barcode.data.decode("utf-8")
             self.er_data = barcodeData
             self.QR_code_data = self.er_data
-        self.name_windows('Result of QRcode')
-        self.show_image('Result of QRcode', img)
+        # self.name_windows('Result of QRcode')
+        # self.show_image('Result of QRcode', img)
+        cv2.imshow('Result of QRcode', img)
 
     def erweima_detect(self):
         img = self.img
@@ -393,4 +394,4 @@ class basicImg():
         M = cv2.moments(c)
         cx = int(M["m10"] / M["m00"])
         cy = int(M["m01"] / M["m00"])
-        return [cx, cy]
+        return [cx, cy]
\ No newline at end of file
